@@ -83,7 +83,7 @@ class BaseDualNetworkedServers(object):
                 kwargs["ipv6"] = ip_version
                 new_address = (server_address[0],) + (port,) + server_address[2:]
                 new_args = (new_address,) + remaining_args
-                server = ServerClass(*new_args, **kwargs) # pylint: disable=star-args
+                server = ServerClass(*new_args, **kwargs)
                 logger.debug(
                     "Successfully bound to %s:%s using %s", new_address[0],
                     new_address[1], "IPv6" if ip_version else "IPv4")
@@ -91,8 +91,8 @@ class BaseDualNetworkedServers(object):
                 if self.servers:
                     # Already bound using IPv6.
                     logger.debug(
-                        "Certbot wasn't able to bind to %s:%s using %s, this " +
-                        "is often expected due to the dual stack nature of " +
+                        "Certbot wasn't able to bind to %s:%s using %s, this "
+                        "is often expected due to the dual stack nature of "
                         "IPv6 socket implementations.",
                         new_address[0], new_address[1],
                         "IPv6" if ip_version else "IPv4")
@@ -105,7 +105,7 @@ class BaseDualNetworkedServers(object):
                 # If two servers are set up and port 0 was passed in, ensure we always
                 # bind to the same port for both servers.
                 port = server.socket.getsockname()[1]
-        if len(self.servers) == 0:
+        if not self.servers:
             raise socket.error("Could not bind to IPv4 or IPv6.")
 
     def serve_forever(self):
